<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- See http://geekswithblogs.net/workdog/archive/2007/02/08/105858.aspx -->
<!-- input  date format: Jul 24, 2008 12:12:12 PM -->
<!-- output date format: 2006-01-14T08:55:22 (ISO 8601) -->

<xsl:template name="toISODateTime">
  <xsl:param name="DateTime" />

  <xsl:variable name="mo">
    <xsl:value-of select="substring($DateTime,1,3)" />
  </xsl:variable>

  <xsl:variable name="day-temp">
    <xsl:value-of select="substring-after($DateTime,' ')" />
  </xsl:variable>

  <xsl:variable name="day">
    <xsl:value-of select="substring-before($day-temp,',')" />
  </xsl:variable>

  <xsl:variable name="year-temp">
    <xsl:value-of select="substring-after($day-temp,' ')" />
  </xsl:variable>

  <xsl:variable name="year">
    <xsl:value-of select="substring($year-temp,1,4)" />
  </xsl:variable>

  <xsl:variable name="time">
    <xsl:value-of select="substring-after($year-temp,' ')" />
  </xsl:variable>

  <xsl:variable name="hh">
    <xsl:value-of select="substring($time,1,2)" />
  </xsl:variable>

  <xsl:variable name="mm">
    <xsl:value-of select="substring($time,4,2)" />
  </xsl:variable>

  <xsl:variable name="ss">
    <xsl:value-of select="substring($time,7,2)" />
  </xsl:variable>

  <xsl:variable name="ampm">
    <xsl:value-of select="substring($time,10,2)" />
  </xsl:variable>

  <!-- output -->

  <xsl:value-of select="$year"/>
  <xsl:value-of select="'-'"/>
  <xsl:choose>
    <xsl:when test="$mo = 'Jan'">01</xsl:when>
    <xsl:when test="$mo = 'Feb'">02</xsl:when>
    <xsl:when test="$mo = 'Mar'">03</xsl:when>
    <xsl:when test="$mo = 'Apr'">04</xsl:when>
    <xsl:when test="$mo = 'May'">05</xsl:when>
    <xsl:when test="$mo = 'Jun'">06</xsl:when>
    <xsl:when test="$mo = 'Jul'">07</xsl:when>
    <xsl:when test="$mo = 'Aug'">08</xsl:when>
    <xsl:when test="$mo = 'Sep'">09</xsl:when>
    <xsl:when test="$mo = 'Oct'">10</xsl:when>
    <xsl:when test="$mo = 'Nov'">11</xsl:when>
    <xsl:when test="$mo = 'Dec'">12</xsl:when>
  </xsl:choose>
  <xsl:value-of select="'-'"/>
  <xsl:if test="(string-length($day) &lt; 2)">
    <xsl:value-of select="0"/>
  </xsl:if>
  <xsl:value-of select="$day"/>
  <xsl:value-of select="'T'"/>
  <xsl:choose>
    <xsl:when test="$ampm = 'PM' and $hh &lt; 12">
      <xsl:value-of select="$hh + 12"/>
    </xsl:when>
    <xsl:when test="$ampm = 'AM' and $hh = 12">
      <xsl:value-of select="'00'"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="$hh"/>
    </xsl:otherwise>
  </xsl:choose>
  <xsl:value-of select="':'"/>
  <xsl:value-of select="$mm"/>
  <xsl:value-of select="':'"/>
  <xsl:value-of select="$ss"/>
</xsl:template>

<xsl:template match="/">
  <office:document-content xmlns:office="urn:oasis:names:tc:opendocument:xmlns:office:1.0" xmlns:style="urn:oasis:names:tc:opendocument:xmlns:style:1.0" xmlns:text="urn:oasis:names:tc:opendocument:xmlns:text:1.0" xmlns:table="urn:oasis:names:tc:opendocument:xmlns:table:1.0" xmlns:draw="urn:oasis:names:tc:opendocument:xmlns:drawing:1.0" xmlns:fo="urn:oasis:names:tc:opendocument:xmlns:xsl-fo-compatible:1.0" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:meta="urn:oasis:names:tc:opendocument:xmlns:meta:1.0" xmlns:number="urn:oasis:names:tc:opendocument:xmlns:datastyle:1.0" xmlns:presentation="urn:oasis:names:tc:opendocument:xmlns:presentation:1.0" xmlns:svg="urn:oasis:names:tc:opendocument:xmlns:svg-compatible:1.0" xmlns:chart="urn:oasis:names:tc:opendocument:xmlns:chart:1.0" xmlns:dr3d="urn:oasis:names:tc:opendocument:xmlns:dr3d:1.0" xmlns:math="http://www.w3.org/1998/Math/MathML" xmlns:form="urn:oasis:names:tc:opendocument:xmlns:form:1.0" xmlns:script="urn:oasis:names:tc:opendocument:xmlns:script:1.0" xmlns:ooo="http://openoffice.org/2004/office" xmlns:ooow="http://openoffice.org/2004/writer" xmlns:oooc="http://openoffice.org/2004/calc" xmlns:dom="http://www.w3.org/2001/xml-events" xmlns:xforms="http://www.w3.org/2002/xforms" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" office:version="1.1">

    <office:automatic-styles>

    <!-- Column styles: set column widths -->
    <style:style style:name="co1" style:family="table-column">
      <style:table-column-properties fo:break-before="auto" style:column-width="0.6in"/>
    </style:style>
    <style:style style:name="co2" style:family="table-column">
      <style:table-column-properties fo:break-before="auto" style:column-width="0.3in"/>
    </style:style>
    <style:style style:name="co3" style:family="table-column">
      <style:table-column-properties fo:break-before="auto" style:column-width="1.5in"/>
    </style:style>

    <!-- Custom date format, style N116: Jul 22, 2008 21:00:01 -->
    <number:date-style style:name="N116">
      <number:month number:textual="true"/>
        <number:text><xsl:text> </xsl:text></number:text>
      <number:day number:style="long"/>
        <number:text><xsl:text>, </xsl:text></number:text>
      <number:year number:style="long"/>
        <number:text><xsl:text> </xsl:text></number:text>
      <number:hours number:style="long"/>
        <number:text><xsl:text>:</xsl:text></number:text>
      <number:minutes number:style="long"/>
        <number:text><xsl:text>:</xsl:text></number:text>
      <number:seconds number:style="long"/>
    </number:date-style>

    <!-- Cell styles (ce1: date) -->
    <style:style style:name="ce1" style:family="table-cell" style:parent-style-name="Default" style:data-style-name="N116"/>

   </office:automatic-styles>

   <office:body>
    <office:spreadsheet>
     <table:table>

      <!-- Format the first 3 columns of the table -->
      <table:table-column table:style-name="co1" table:default-cell-style-name="Default"/>
      <table:table-column table:style-name="co2" table:default-cell-style-name="Default"/>
      <table:table-column table:style-name="co3" table:default-cell-style-name="ce1"/>

      <!-- no column labels -->

      <!-- Process XML input: Insert one row for each payment -->
      <xsl:for-each select="report/r">
       <table:table-row>

        <!-- Insert report/r/a -->
        <table:table-cell office:value-type="float">
         <xsl:attribute name="office:value"><xsl:value-of select="a"/></xsl:attribute>
         <text:p><xsl:value-of select="a"/></text:p>
        </table:table-cell>

        <!-- Insert report/r/m -->
        <table:table-cell office:value-type="float">
         <xsl:attribute name="office:value"><xsl:value-of select="m"/></xsl:attribute>
         <text:p><xsl:value-of select="m"/></text:p>
        </table:table-cell>

        <!-- Insert report/r/p -->
        <table:table-cell office:value-type="date">
         <xsl:attribute name="office:date-value">
           <xsl:call-template name="toISODateTime">
             <xsl:with-param name="DateTime" select="p"/>
           </xsl:call-template>
	 </xsl:attribute>
         <text:p><xsl:value-of select="p"/></text:p>
        </table:table-cell>

       </table:table-row>
      </xsl:for-each>
     </table:table>
    </office:spreadsheet>
   </office:body>
  </office:document-content>
</xsl:template>
</xsl:stylesheet>
